<?php
/**
 * Plugin Name: Disable All Updates and Notifications
 * Description: Disables all update notifications, auto-updates for plugins, themes, and WordPress core, and removes core update notifications.
 * Version: 1.2
 * Author: Cassus Media LLC
 */

// Disable update notifications
function disable_all_update_notifications() {
    remove_action('load-update-core.php', 'wp_update_plugins');
    add_filter('pre_site_transient_update_plugins', '__return_null');

    remove_action('load-update-core.php', 'wp_update_themes');
    add_filter('pre_site_transient_update_themes', '__return_null');
}
add_action('admin_init', 'disable_all_update_notifications');

// Disable auto-updates
add_filter('auto_update_plugin', '__return_false');
add_filter('auto_update_theme', '__return_false');
add_filter('auto_update_core', '__return_false');

// Remove core update notifications
function remove_core_update_notification() {
    global $wp_version;
    return (object) array(
        'current' => $wp_version,
        'latest' => $wp_version,
        'response' => ''
    );
}
add_filter('site_transient_update_core', 'remove_core_update_notification');
